# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ...core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .get_batch_root_response_results_item import GetBatchRootResponseResultsItem


class GetBatchRootResponse(UniversalBaseModel):
    count: typing.Optional[int] = pydantic.Field(default=None)
    """
    Total number of batches matching the filter
    """

    results: typing.Optional[typing.List[GetBatchRootResponseResultsItem]] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
