# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ...core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .get_dimensions_root_response_dimensions_item import GetDimensionsRootResponseDimensionsItem


class GetDimensionsRootResponse(UniversalBaseModel):
    version: str
    count: int
    page: int
    limit: int
    dimensions: typing.List[GetDimensionsRootResponseDimensionsItem]

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
