# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class InvoiceDetailObjectPaymentInfo(UniversalBaseModel):
    """
    Payment information (only present if payment_status is 'paid')
    """

    payment_method: typing.Optional[str] = pydantic.Field(default=None)
    """
    Method used for payment
    """

    reference: typing.Optional[str] = pydantic.Field(default=None)
    """
    Payment reference number
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
