# This file was auto-generated by Fern from our API Definition.

import typing

ReceiptUpdateResponseStatus = typing.Union[
    typing.Literal["open", "pending", "flagged", "closed", "archived", "deleted"], typing.Any
]
