# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class InvoiceCreationResponseContainer(UniversalBaseModel):
    """
    File container information
    """

    id: int = pydantic.Field()
    """
    Container ID
    """

    filename: str = pydantic.Field()
    """
    Stored filename
    """

    file_size: typing.Optional[int] = pydantic.Field(default=None)
    """
    File size in bytes
    """

    content_type: typing.Optional[str] = pydantic.Field(default=None)
    """
    MIME type of uploaded file
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
