# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ...core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ...core.serialization import FieldMetadata
from .post_vendors_bulk_response_updated_item_payment_method import PostVendorsBulkResponseUpdatedItemPaymentMethod


class PostVendorsBulkResponseUpdatedItem(UniversalBaseModel):
    id: typing.Optional[int] = None
    ottimate_company_id: typing.Optional[int] = None
    erp_vendor_id: typing.Optional[str] = None
    erp_vendor_name: typing.Optional[str] = None
    email: typing.Optional[str] = None
    phone: typing.Optional[str] = None
    net_terms: typing.Optional[str] = None
    payment_method: typing.Optional[PostVendorsBulkResponseUpdatedItemPaymentMethod] = None
    address_line1: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="address_line_1")] = None
    address_line2: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="address_line_2")] = None
    city: typing.Optional[str] = None
    state: typing.Optional[str] = None
    zipcode: typing.Optional[str] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
