# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .invoice_creation_response_invoice_status import InvoiceCreationResponseInvoiceStatus


class InvoiceCreationResponseInvoice(UniversalBaseModel):
    """
    Created invoice details
    """

    id: str = pydantic.Field()
    """
    Unique invoice identifier
    """

    status: InvoiceCreationResponseInvoiceStatus = pydantic.Field()
    """
    Initial processing status
    """

    created_at: dt.datetime = pydantic.Field()
    """
    Invoice creation timestamp
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
