# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

import typing
from importlib import import_module

if typing.TYPE_CHECKING:
    from .get_dimensions_id_response import GetDimensionsIdResponse
    from .get_dimensions_id_response_dimension import GetDimensionsIdResponseDimension
    from .get_dimensions_id_response_dimension_ottimate_type import GetDimensionsIdResponseDimensionOttimateType
    from .get_dimensions_root_response import GetDimensionsRootResponse
    from .get_dimensions_root_response_dimensions_item import GetDimensionsRootResponseDimensionsItem
    from .get_dimensions_root_response_dimensions_item_ottimate_type import (
        GetDimensionsRootResponseDimensionsItemOttimateType,
    )
    from .post_dimensions_bulk_request_dimensions_item import PostDimensionsBulkRequestDimensionsItem
    from .post_dimensions_bulk_request_dimensions_item_ottimate_type import (
        PostDimensionsBulkRequestDimensionsItemOttimateType,
    )
    from .post_dimensions_bulk_response import PostDimensionsBulkResponse
    from .post_dimensions_bulk_response_created_item import PostDimensionsBulkResponseCreatedItem
    from .post_dimensions_bulk_response_errors_item import PostDimensionsBulkResponseErrorsItem
    from .post_dimensions_bulk_response_updated_item import PostDimensionsBulkResponseUpdatedItem
    from .post_dimensions_root_request_ottimate_type import PostDimensionsRootRequestOttimateType
    from .post_dimensions_root_response import PostDimensionsRootResponse
    from .post_dimensions_root_response_ottimate_type import PostDimensionsRootResponseOttimateType
_dynamic_imports: typing.Dict[str, str] = {
    "GetDimensionsIdResponse": ".get_dimensions_id_response",
    "GetDimensionsIdResponseDimension": ".get_dimensions_id_response_dimension",
    "GetDimensionsIdResponseDimensionOttimateType": ".get_dimensions_id_response_dimension_ottimate_type",
    "GetDimensionsRootResponse": ".get_dimensions_root_response",
    "GetDimensionsRootResponseDimensionsItem": ".get_dimensions_root_response_dimensions_item",
    "GetDimensionsRootResponseDimensionsItemOttimateType": ".get_dimensions_root_response_dimensions_item_ottimate_type",
    "PostDimensionsBulkRequestDimensionsItem": ".post_dimensions_bulk_request_dimensions_item",
    "PostDimensionsBulkRequestDimensionsItemOttimateType": ".post_dimensions_bulk_request_dimensions_item_ottimate_type",
    "PostDimensionsBulkResponse": ".post_dimensions_bulk_response",
    "PostDimensionsBulkResponseCreatedItem": ".post_dimensions_bulk_response_created_item",
    "PostDimensionsBulkResponseErrorsItem": ".post_dimensions_bulk_response_errors_item",
    "PostDimensionsBulkResponseUpdatedItem": ".post_dimensions_bulk_response_updated_item",
    "PostDimensionsRootRequestOttimateType": ".post_dimensions_root_request_ottimate_type",
    "PostDimensionsRootResponse": ".post_dimensions_root_response",
    "PostDimensionsRootResponseOttimateType": ".post_dimensions_root_response_ottimate_type",
}


def __getattr__(attr_name: str) -> typing.Any:
    module_name = _dynamic_imports.get(attr_name)
    if module_name is None:
        raise AttributeError(f"No {attr_name} found in _dynamic_imports for module name -> {__name__}")
    try:
        module = import_module(module_name, __package__)
        if module_name == f".{attr_name}":
            return module
        else:
            return getattr(module, attr_name)
    except ImportError as e:
        raise ImportError(f"Failed to import {attr_name} from {module_name}: {e}") from e
    except AttributeError as e:
        raise AttributeError(f"Failed to get {attr_name} from {module_name}: {e}") from e


def __dir__():
    lazy_attrs = list(_dynamic_imports.keys())
    return sorted(lazy_attrs)


__all__ = [
    "GetDimensionsIdResponse",
    "GetDimensionsIdResponseDimension",
    "GetDimensionsIdResponseDimensionOttimateType",
    "GetDimensionsRootResponse",
    "GetDimensionsRootResponseDimensionsItem",
    "GetDimensionsRootResponseDimensionsItemOttimateType",
    "PostDimensionsBulkRequestDimensionsItem",
    "PostDimensionsBulkRequestDimensionsItemOttimateType",
    "PostDimensionsBulkResponse",
    "PostDimensionsBulkResponseCreatedItem",
    "PostDimensionsBulkResponseErrorsItem",
    "PostDimensionsBulkResponseUpdatedItem",
    "PostDimensionsRootRequestOttimateType",
    "PostDimensionsRootResponse",
    "PostDimensionsRootResponseOttimateType",
]
