# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .receipt_bulk_upsert_async_response_summary import ReceiptBulkUpsertAsyncResponseSummary


class ReceiptBulkUpsertAsyncResponse(UniversalBaseModel):
    version: typing.Optional[str] = None
    status: typing.Literal["processing"] = "processing"
    batch_id: str
    batch_url: typing.Optional[str] = None
    results_url: typing.Optional[str] = None
    summary: typing.Optional[ReceiptBulkUpsertAsyncResponseSummary] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
