# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

import typing
from importlib import import_module

if typing.TYPE_CHECKING:
    from .catalog_allowance_bulk_create_request_allowances_item import CatalogAllowanceBulkCreateRequestAllowancesItem
    from .catalog_allowance_bulk_create_request_allowances_item_allowance_type import (
        CatalogAllowanceBulkCreateRequestAllowancesItemAllowanceType,
    )
    from .catalog_entry_bulk_create_request_entries_item import CatalogEntryBulkCreateRequestEntriesItem
    from .catalog_entry_bulk_create_request_entries_item_allowances_item import (
        CatalogEntryBulkCreateRequestEntriesItemAllowancesItem,
    )
    from .catalog_entry_bulk_create_request_entries_item_allowances_item_allowance_type import (
        CatalogEntryBulkCreateRequestEntriesItemAllowancesItemAllowanceType,
    )
    from .catalog_entry_bulk_create_request_entries_item_prices_item import (
        CatalogEntryBulkCreateRequestEntriesItemPricesItem,
    )
    from .catalog_entry_bulk_create_request_entries_item_prices_item_price_type import (
        CatalogEntryBulkCreateRequestEntriesItemPricesItemPriceType,
    )
    from .catalog_prices_bulk_create_request_prices_item import CatalogPricesBulkCreateRequestPricesItem
    from .catalog_prices_bulk_create_request_prices_item_price_type import (
        CatalogPricesBulkCreateRequestPricesItemPriceType,
    )
    from .get_catalog_prices_request_price_type import GetCatalogPricesRequestPriceType
    from .get_catalog_prices_response import GetCatalogPricesResponse
    from .get_catalog_variances_request_exception_type import GetCatalogVariancesRequestExceptionType
    from .patch_catalog_allowances_id_request_allowance_type import PatchCatalogAllowancesIdRequestAllowanceType
    from .patch_catalog_entries_id_request_properties import PatchCatalogEntriesIdRequestProperties
    from .post_catalog_allowances_request_allowance_type import PostCatalogAllowancesRequestAllowanceType
    from .post_catalog_entries_request_allowances_item import PostCatalogEntriesRequestAllowancesItem
    from .post_catalog_entries_request_prices_item import PostCatalogEntriesRequestPricesItem
    from .post_catalog_entries_request_prices_item_price_type import PostCatalogEntriesRequestPricesItemPriceType
    from .post_catalog_prices_bulk_response import PostCatalogPricesBulkResponse
    from .post_catalog_prices_request_price_type import PostCatalogPricesRequestPriceType
_dynamic_imports: typing.Dict[str, str] = {
    "CatalogAllowanceBulkCreateRequestAllowancesItem": ".catalog_allowance_bulk_create_request_allowances_item",
    "CatalogAllowanceBulkCreateRequestAllowancesItemAllowanceType": ".catalog_allowance_bulk_create_request_allowances_item_allowance_type",
    "CatalogEntryBulkCreateRequestEntriesItem": ".catalog_entry_bulk_create_request_entries_item",
    "CatalogEntryBulkCreateRequestEntriesItemAllowancesItem": ".catalog_entry_bulk_create_request_entries_item_allowances_item",
    "CatalogEntryBulkCreateRequestEntriesItemAllowancesItemAllowanceType": ".catalog_entry_bulk_create_request_entries_item_allowances_item_allowance_type",
    "CatalogEntryBulkCreateRequestEntriesItemPricesItem": ".catalog_entry_bulk_create_request_entries_item_prices_item",
    "CatalogEntryBulkCreateRequestEntriesItemPricesItemPriceType": ".catalog_entry_bulk_create_request_entries_item_prices_item_price_type",
    "CatalogPricesBulkCreateRequestPricesItem": ".catalog_prices_bulk_create_request_prices_item",
    "CatalogPricesBulkCreateRequestPricesItemPriceType": ".catalog_prices_bulk_create_request_prices_item_price_type",
    "GetCatalogPricesRequestPriceType": ".get_catalog_prices_request_price_type",
    "GetCatalogPricesResponse": ".get_catalog_prices_response",
    "GetCatalogVariancesRequestExceptionType": ".get_catalog_variances_request_exception_type",
    "PatchCatalogAllowancesIdRequestAllowanceType": ".patch_catalog_allowances_id_request_allowance_type",
    "PatchCatalogEntriesIdRequestProperties": ".patch_catalog_entries_id_request_properties",
    "PostCatalogAllowancesRequestAllowanceType": ".post_catalog_allowances_request_allowance_type",
    "PostCatalogEntriesRequestAllowancesItem": ".post_catalog_entries_request_allowances_item",
    "PostCatalogEntriesRequestPricesItem": ".post_catalog_entries_request_prices_item",
    "PostCatalogEntriesRequestPricesItemPriceType": ".post_catalog_entries_request_prices_item_price_type",
    "PostCatalogPricesBulkResponse": ".post_catalog_prices_bulk_response",
    "PostCatalogPricesRequestPriceType": ".post_catalog_prices_request_price_type",
}


def __getattr__(attr_name: str) -> typing.Any:
    module_name = _dynamic_imports.get(attr_name)
    if module_name is None:
        raise AttributeError(f"No {attr_name} found in _dynamic_imports for module name -> {__name__}")
    try:
        module = import_module(module_name, __package__)
        if module_name == f".{attr_name}":
            return module
        else:
            return getattr(module, attr_name)
    except ImportError as e:
        raise ImportError(f"Failed to import {attr_name} from {module_name}: {e}") from e
    except AttributeError as e:
        raise AttributeError(f"Failed to get {attr_name} from {module_name}: {e}") from e


def __dir__():
    lazy_attrs = list(_dynamic_imports.keys())
    return sorted(lazy_attrs)


__all__ = [
    "CatalogAllowanceBulkCreateRequestAllowancesItem",
    "CatalogAllowanceBulkCreateRequestAllowancesItemAllowanceType",
    "CatalogEntryBulkCreateRequestEntriesItem",
    "CatalogEntryBulkCreateRequestEntriesItemAllowancesItem",
    "CatalogEntryBulkCreateRequestEntriesItemAllowancesItemAllowanceType",
    "CatalogEntryBulkCreateRequestEntriesItemPricesItem",
    "CatalogEntryBulkCreateRequestEntriesItemPricesItemPriceType",
    "CatalogPricesBulkCreateRequestPricesItem",
    "CatalogPricesBulkCreateRequestPricesItemPriceType",
    "GetCatalogPricesRequestPriceType",
    "GetCatalogPricesResponse",
    "GetCatalogVariancesRequestExceptionType",
    "PatchCatalogAllowancesIdRequestAllowanceType",
    "PatchCatalogEntriesIdRequestProperties",
    "PostCatalogAllowancesRequestAllowanceType",
    "PostCatalogEntriesRequestAllowancesItem",
    "PostCatalogEntriesRequestPricesItem",
    "PostCatalogEntriesRequestPricesItemPriceType",
    "PostCatalogPricesBulkResponse",
    "PostCatalogPricesRequestPriceType",
]
