# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .variance_list_response_results_item_last_invoice_item import VarianceListResponseResultsItemLastInvoiceItem


class VarianceListResponseResultsItem(UniversalBaseModel):
    id: str = pydantic.Field()
    """
    Catalog entry ID
    """

    item_name: str
    sku: typing.Optional[str] = None
    upc: typing.Optional[str] = None
    pack_size: typing.Optional[str] = None
    erp_vendor_id: typing.Optional[str] = pydantic.Field(default=None)
    """
    ERP Vendor id from ERP/accounting system
    """

    last_invoice_item: typing.Optional[VarianceListResponseResultsItemLastInvoiceItem] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
