# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ...core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .post_vendors_bulk_response_created_item import PostVendorsBulkResponseCreatedItem
from .post_vendors_bulk_response_errors_item import PostVendorsBulkResponseErrorsItem
from .post_vendors_bulk_response_updated_item import PostVendorsBulkResponseUpdatedItem


class PostVendorsBulkResponse(UniversalBaseModel):
    version: typing.Optional[str] = None
    success_count: typing.Optional[int] = None
    created_count: typing.Optional[int] = None
    updated_count: typing.Optional[int] = None
    error_count: typing.Optional[int] = None
    created: typing.Optional[typing.List[PostVendorsBulkResponseCreatedItem]] = None
    updated: typing.Optional[typing.List[PostVendorsBulkResponseUpdatedItem]] = None
    errors: typing.Optional[typing.List[PostVendorsBulkResponseErrorsItem]] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
