# This file was auto-generated by Fern from our API Definition.

import typing

GetVendorsRootResponseVendorsItemPaymentMethod = typing.Union[
    typing.Literal["credit_card", "ach", "check", "wire_transfer", "unknown"], typing.Any
]
