# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

import typing
from importlib import import_module

if typing.TYPE_CHECKING:
    from .get_vendors_id_response import GetVendorsIdResponse
    from .get_vendors_id_response_vendor import GetVendorsIdResponseVendor
    from .get_vendors_id_response_vendor_payment_method import GetVendorsIdResponseVendorPaymentMethod
    from .get_vendors_root_response import GetVendorsRootResponse
    from .get_vendors_root_response_vendors_item import GetVendorsRootResponseVendorsItem
    from .get_vendors_root_response_vendors_item_payment_method import GetVendorsRootResponseVendorsItemPaymentMethod
    from .post_vendors_bulk_request_vendors_item import PostVendorsBulkRequestVendorsItem
    from .post_vendors_bulk_request_vendors_item_payment_method import PostVendorsBulkRequestVendorsItemPaymentMethod
    from .post_vendors_bulk_response import PostVendorsBulkResponse
    from .post_vendors_bulk_response_created_item import PostVendorsBulkResponseCreatedItem
    from .post_vendors_bulk_response_created_item_payment_method import PostVendorsBulkResponseCreatedItemPaymentMethod
    from .post_vendors_bulk_response_errors_item import PostVendorsBulkResponseErrorsItem
    from .post_vendors_bulk_response_updated_item import PostVendorsBulkResponseUpdatedItem
    from .post_vendors_bulk_response_updated_item_payment_method import PostVendorsBulkResponseUpdatedItemPaymentMethod
    from .post_vendors_root_request_payment_method import PostVendorsRootRequestPaymentMethod
    from .post_vendors_root_response import PostVendorsRootResponse
    from .post_vendors_root_response_vendor import PostVendorsRootResponseVendor
    from .post_vendors_root_response_vendor_payment_method import PostVendorsRootResponseVendorPaymentMethod
_dynamic_imports: typing.Dict[str, str] = {
    "GetVendorsIdResponse": ".get_vendors_id_response",
    "GetVendorsIdResponseVendor": ".get_vendors_id_response_vendor",
    "GetVendorsIdResponseVendorPaymentMethod": ".get_vendors_id_response_vendor_payment_method",
    "GetVendorsRootResponse": ".get_vendors_root_response",
    "GetVendorsRootResponseVendorsItem": ".get_vendors_root_response_vendors_item",
    "GetVendorsRootResponseVendorsItemPaymentMethod": ".get_vendors_root_response_vendors_item_payment_method",
    "PostVendorsBulkRequestVendorsItem": ".post_vendors_bulk_request_vendors_item",
    "PostVendorsBulkRequestVendorsItemPaymentMethod": ".post_vendors_bulk_request_vendors_item_payment_method",
    "PostVendorsBulkResponse": ".post_vendors_bulk_response",
    "PostVendorsBulkResponseCreatedItem": ".post_vendors_bulk_response_created_item",
    "PostVendorsBulkResponseCreatedItemPaymentMethod": ".post_vendors_bulk_response_created_item_payment_method",
    "PostVendorsBulkResponseErrorsItem": ".post_vendors_bulk_response_errors_item",
    "PostVendorsBulkResponseUpdatedItem": ".post_vendors_bulk_response_updated_item",
    "PostVendorsBulkResponseUpdatedItemPaymentMethod": ".post_vendors_bulk_response_updated_item_payment_method",
    "PostVendorsRootRequestPaymentMethod": ".post_vendors_root_request_payment_method",
    "PostVendorsRootResponse": ".post_vendors_root_response",
    "PostVendorsRootResponseVendor": ".post_vendors_root_response_vendor",
    "PostVendorsRootResponseVendorPaymentMethod": ".post_vendors_root_response_vendor_payment_method",
}


def __getattr__(attr_name: str) -> typing.Any:
    module_name = _dynamic_imports.get(attr_name)
    if module_name is None:
        raise AttributeError(f"No {attr_name} found in _dynamic_imports for module name -> {__name__}")
    try:
        module = import_module(module_name, __package__)
        if module_name == f".{attr_name}":
            return module
        else:
            return getattr(module, attr_name)
    except ImportError as e:
        raise ImportError(f"Failed to import {attr_name} from {module_name}: {e}") from e
    except AttributeError as e:
        raise AttributeError(f"Failed to get {attr_name} from {module_name}: {e}") from e


def __dir__():
    lazy_attrs = list(_dynamic_imports.keys())
    return sorted(lazy_attrs)


__all__ = [
    "GetVendorsIdResponse",
    "GetVendorsIdResponseVendor",
    "GetVendorsIdResponseVendorPaymentMethod",
    "GetVendorsRootResponse",
    "GetVendorsRootResponseVendorsItem",
    "GetVendorsRootResponseVendorsItemPaymentMethod",
    "PostVendorsBulkRequestVendorsItem",
    "PostVendorsBulkRequestVendorsItemPaymentMethod",
    "PostVendorsBulkResponse",
    "PostVendorsBulkResponseCreatedItem",
    "PostVendorsBulkResponseCreatedItemPaymentMethod",
    "PostVendorsBulkResponseErrorsItem",
    "PostVendorsBulkResponseUpdatedItem",
    "PostVendorsBulkResponseUpdatedItemPaymentMethod",
    "PostVendorsRootRequestPaymentMethod",
    "PostVendorsRootResponse",
    "PostVendorsRootResponseVendor",
    "PostVendorsRootResponseVendorPaymentMethod",
]
