# This file was auto-generated by Fern from our API Definition.

import typing

CatalogEntryObjectPricesItemPriceTypeDisplay = typing.Union[
    typing.Literal["company", "location_group", "location"], typing.Any
]
