# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class CatalogBulkSkippedItem(UniversalBaseModel):
    """
    Details for a skipped item in bulk operation
    """

    index: int = pydantic.Field()
    """
    Index of the skipped item in the request array
    """

    reference_id: typing.Optional[str] = pydantic.Field(default=None)
    """
    Reference ID of the skipped item
    """

    reason: str = pydantic.Field()
    """
    Reason why the item was skipped
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
