# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ...core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .receipt_bulk_upsert_request_receipts_item_items_item import ReceiptBulkUpsertRequestReceiptsItemItemsItem


class ReceiptBulkUpsertRequestReceiptsItem(UniversalBaseModel):
    """
    To identify the PO, provide either ottimate_po_id OR erp_vendor_id + ottimate_location_id + (po_number OR po_external_id).
    """

    ottimate_po_id: typing.Optional[str] = pydantic.Field(default=None)
    """
    Ottimate-assigned PO ID. Required unless using PO lookup fields.
    """

    ottimate_location_id: typing.Optional[int] = pydantic.Field(default=None)
    """
    Location (restaurant) ID for PO lookup. Required when using lookup fields instead of ottimate_po_id.
    """

    erp_vendor_id: typing.Optional[str] = pydantic.Field(default=None)
    """
    ERP vendor ID for PO lookup.
    """

    po_number: typing.Optional[str] = pydantic.Field(default=None)
    """
    PO number for lookup.
    """

    po_external_id: typing.Optional[str] = pydantic.Field(default=None)
    """
    External ID (dd_unique_key) of the PO for lookup. Alternative to po_number.
    """

    external_id: typing.Optional[str] = None
    receipt_number: str
    date: str
    total_amount: float
    invoice_number_ref: typing.Optional[str] = pydantic.Field(default=None)
    """
    Invoice reference number
    """

    note: typing.Optional[str] = None
    items: typing.List[ReceiptBulkUpsertRequestReceiptsItemItemsItem]

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
