# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .catalog_entry_list_response_results_item import CatalogEntryListResponseResultsItem


class CatalogEntryListResponse(UniversalBaseModel):
    count: int = pydantic.Field()
    """
    Total number of results
    """

    results: typing.List[CatalogEntryListResponseResultsItem] = pydantic.Field()
    """
    List of catalog entries (uses CatalogEntryBasicObject by default, CatalogEntryObject when expand is used)
    """

    page: typing.Optional[int] = pydantic.Field(default=None)
    """
    Current page number
    """

    per_page: typing.Optional[int] = pydantic.Field(default=None)
    """
    Items per page
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
