# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class InstantCaptureFileObject(UniversalBaseModel):
    id: str = pydantic.Field()
    """
    Unique file identifier
    """

    filename: str = pydantic.Field()
    """
    Name of the file
    """

    status: str = pydantic.Field()
    """
    Processing status of the file
    """

    date: dt.datetime = pydantic.Field()
    """
    Date when the file was uploaded
    """

    no_of_pages: int = pydantic.Field()
    """
    Number of pages in the file
    """

    ottimate_location_name: typing.Optional[str] = pydantic.Field(default=None)
    """
    Name of the location
    """

    preview_url: typing.Optional[str] = pydantic.Field(default=None)
    """
    URL to preview the file
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
