# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class InvoiceDetailObjectGlSplitsItem(UniversalBaseModel):
    memo: typing.Optional[str] = pydantic.Field(default=None)
    """
    Optional note on the split
    """

    amount: typing.Optional[str] = pydantic.Field(default=None)
    """
    Split amount formatted to 2 decimal places
    """

    custom_fields: typing.Optional[typing.Dict[str, typing.Any]] = pydantic.Field(default=None)
    """
    Custom metadata fields for this split
    """

    dimensions: typing.Optional[typing.Dict[str, typing.Any]] = pydantic.Field(default=None)
    """
    Accounting dimensions for this split. Same structure as header-level dimensions. Keys are dimension type codes.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
