# This file was auto-generated by Fern from our API Definition.

import typing

GetDimensionsIdResponseDimensionOttimateType = typing.Union[
    typing.Literal[
        "account",
        "location",
        "department",
        "class",
        "project",
        "customer",
        "entity",
        "item",
        "warehouse",
        "task",
        "costtype",
        "employee",
        "taxcode",
        "property",
        "company",
        "subsidiary",
    ],
    typing.Any,
]
