# This file was auto-generated by Fern from our API Definition.

import typing

InvoiceCreationResponseProcessingStatus = typing.Union[typing.Literal["initiated", "queued", "in_progress"], typing.Any]
