# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class CatalogBulkResponseSkippedItem(UniversalBaseModel):
    """
    An entry skipped because it already exists with identical data
    """

    id: typing.Optional[str] = pydantic.Field(default=None)
    """
    Catalog entry ID
    """

    ottimate_company_id: typing.Optional[int] = None
    reference_id: typing.Optional[str] = None
    catalog_unique_key: typing.Optional[str] = None
    description: typing.Optional[str] = None
    sku: typing.Optional[str] = None
    erp_vendor_id: typing.Optional[str] = None
    reason: typing.Optional[str] = pydantic.Field(default=None)
    """
    Always: 'Entry already exists with identical data. No changes detected.'
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
