# This file was auto-generated by Fern from our API Definition.

import enum


class OttimateEnvironment(enum.Enum):
    PRODUCTION = "https://api.ottimate.com/v1"
    SANDBOX = "https://sandbox-api.ottimate.com/v1"
