# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .batch_results_response_results_item import BatchResultsResponseResultsItem


class BatchResultsResponse(UniversalBaseModel):
    version: str
    batch_id: str = pydantic.Field()
    """
    The batch identifier
    """

    results: typing.List[BatchResultsResponseResultsItem] = pydantic.Field()
    """
    One entry per task in the batch
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
