# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ...core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class PatchReceiptsIdRequestItemsItem(UniversalBaseModel):
    id: typing.Optional[str] = pydantic.Field(default=None)
    """
    Existing receipt item ID. If provided, updates that item; if omitted, creates a new item.
    """

    external_id: typing.Optional[str] = None
    ottimate_po_item_id: typing.Optional[str] = pydantic.Field(default=None)
    """
    Required when creating a new item (no id).
    """

    quantity: typing.Optional[float] = pydantic.Field(default=None)
    """
    Required when creating a new item (no id).
    """

    price: typing.Optional[float] = None
    uom: typing.Optional[str] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
