# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ...core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .post_dimensions_bulk_request_dimensions_item_ottimate_type import (
    PostDimensionsBulkRequestDimensionsItemOttimateType,
)


class PostDimensionsBulkRequestDimensionsItem(UniversalBaseModel):
    erp_type: str = pydantic.Field()
    """
    The dimension category label in client's ERP system
    """

    ottimate_type: PostDimensionsBulkRequestDimensionsItemOttimateType = pydantic.Field()
    """
    Ottimate's standardized dimension type code
    """

    name: str = pydantic.Field()
    """
    Display name of the dimension
    """

    code: str = pydantic.Field()
    """
    The GL code or short identifier for this dimension
    """

    reference_id: str = pydantic.Field()
    """
    A unique reference identifier that tracks this dimension across all client systems
    """

    erp_dimension_id: str = pydantic.Field()
    """
    The identifier assigned to this dimension by the client's ERP software
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
