# This file was auto-generated by Fern from our API Definition.

import typing

InvoiceDetailObjectItemsProcessingResultStatus = typing.Union[
    typing.Literal["success", "partial_success", "failure"], typing.Any
]
