# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .invoice_creation_response_processing_status import InvoiceCreationResponseProcessingStatus


class InvoiceCreationResponseProcessing(UniversalBaseModel):
    """
    Asynchronous processing information
    """

    status: InvoiceCreationResponseProcessingStatus = pydantic.Field()
    """
    Processing workflow status
    """

    estimated_completion: typing.Optional[dt.datetime] = pydantic.Field(default=None)
    """
    Estimated processing completion time
    """

    queue_position: typing.Optional[int] = pydantic.Field(default=None)
    """
    Position in processing queue
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
