# This file was auto-generated by Fern from our API Definition.

import typing

CatalogAllowanceNestedObjectAllowanceType = typing.Union[typing.Literal["allowance", "discount", "rebate"], typing.Any]
