# This file was auto-generated by Fern from our API Definition.

import typing

PurchaseOrderUpdateResponseStatus = typing.Union[
    typing.Literal["pending", "open", "received", "closed", "flagged", "archived", "deleted"], typing.Any
]
