# This file was auto-generated by Fern from our API Definition.

import typing

InvoiceCreationResponseUploadUploadMethod = typing.Union[
    typing.Literal["file_upload", "url_download", "public_api"], typing.Any
]
