# This file was auto-generated by Fern from our API Definition.

import typing

GetPurchaseOrdersRootRequestStatus = typing.Union[
    typing.Literal["pending_review", "approved", "rejected", "closed"], typing.Any
]
