# This file was auto-generated by Fern from our API Definition.

import typing

GetInvoicesRootRequestStatus = typing.Union[
    typing.Literal[
        "approved",
        "incomplete",
        "archived",
        "processing",
        "needs-attention",
        "ready-for-export",
        "exported",
        "pending-approval",
    ],
    typing.Any,
]
