# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ...core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .get_dimensions_id_response_dimension_ottimate_type import GetDimensionsIdResponseDimensionOttimateType


class GetDimensionsIdResponseDimension(UniversalBaseModel):
    id: str = pydantic.Field()
    """
    Unique Ottimate dimension identifier
    """

    name: str = pydantic.Field()
    """
    Display name of the dimension
    """

    erp_type: str = pydantic.Field()
    """
    The dimension category label as displayed in the client's ERP system.
    """

    code: typing.Optional[str] = pydantic.Field(default=None)
    """
    The GL code or short identifier associated with this dimension.
    """

    reference_id: typing.Optional[str] = pydantic.Field(default=None)
    """
    A unique reference identifier that tracks this dimension across all client systems.
    """

    ottimate_type: typing.Optional[GetDimensionsIdResponseDimensionOttimateType] = pydantic.Field(default=None)
    """
    Ottimate's standardized dimension type code.
    """

    erp_dimension_id: str = pydantic.Field()
    """
    The identifier assigned to this dimension by the client's ERP software.
    """

    ottimate_company_id: typing.Optional[int] = pydantic.Field(default=None)
    """
    The Ottimate company ID this dimension belongs to
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
