# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata
from .invoice_creation_response_upload_upload_method import InvoiceCreationResponseUploadUploadMethod


class InvoiceCreationResponseUpload(UniversalBaseModel):
    """
    Upload details and storage information
    """

    id: str = pydantic.Field()
    """
    Upload session ID
    """

    s3url: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="s3_url")] = pydantic.Field(
        default=None
    )
    """
    Secure S3 storage URL
    """

    upload_method: InvoiceCreationResponseUploadUploadMethod = pydantic.Field()
    """
    Method used for upload
    """

    upload_source: typing.Optional[str] = pydantic.Field(default=None)
    """
    Source of the upload
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
